/**
 * @file
 * JS functions to support theming in the Janitor theme.
 */

/*
 * Janitor Base Theme : Anton Boshoff
 * ==== INDEX
 * Global variables.
 * Sticky header.
 * Navigation width.
 * Toggle navigation.
 * Expand navigation.
 * Collapse navigation.
 * Mobile toggle expandable items.
 * Collapse mobile expandable items.
 * Add scroll to navigation.
 * Accordion.
 * Tabber.
 * Equal heights.
 * Sidebar height.
 * Disable middle mouse click.
 */


// ==== NAMESPACE.
window.app = {};

// ==== TRIGGER ON DOCUMENT READY.
jQuery(function ($) {

  'use strict';

  app.go.globalVar();
  app.go.stickyHeader();
  app.go.navWidth();
  app.go.toggleNav();
  app.go.mobileMenuItemsToggle();
  app.go.initAccordion();
  app.go.initTabber();
  app.go.disableMiddleMouse();

  var lazyLayout = _.debounce(updateResizeDebounce, 10);
  app.go.win.resize(lazyLayout);

  var rThrottled = _.throttle(updateResizeThrottle, 10);
  app.go.win.resize(rThrottled);

  var sThrottled = _.throttle(updateScrollThrottle, 10);
  app.go.win.scroll(sThrottled);

});

// ==== TRIGGER AFTER PAGE LOAD.
jQuery(window).load(function () {

  'use strict';

  app.go.equalHeights();
  app.go.sidebarHeight();

});

// ==== TRIGGER ON RESIZE ( DEBOUNCE ).
function updateResizeDebounce() {

  'use strict';

}

// ==== TRIGGER ON RESIZE ( THROTTLE ).
function updateResizeThrottle() {

  'use strict';

  // Dynamic values.
  app.go.winWidth = app.go.win.width();

  app.go.equalHeights();
  app.go.sidebarHeight();

  if (app.go.winWidth < 960) {
    app.go.isMobile = true;
  }
  else {
    app.go.isMobile = false;
  }

  app.go.navWidth();

  if (app.go.isMobile === false) {
    app.go.expandNav();
    app.go.mobileMenuItemsCollapse();
    if (jQuery('.header-fixed').length === 0 && jQuery('.header-sticky').length === 0) {
      app.go.body.css({
        overflowY: 'visible',
        position: 'relative'
      });
    }
    app.go.nav.css({
      height: 'auto'
    });
  }
  else {
    app.go.collapseNav();
    if (app.go.spanInit !== true) {
      app.go.mobileMenuItemsToggle();
    }
  }

}

// ==== TRIGGER ON SCROLL ( THROTTLE ).
function updateScrollThrottle() {

  'use strict';

  // Dynamic values.
  app.go.winTop = app.go.win.scrollTop();

  app.go.stickyHeader();

}


// ==== FUNCTIONS.
app.go = {

  // Global variables.
  globalVar: function () {

    'use strict';

    // Variables.
    app.go.win = jQuery(window);
    app.go.body = jQuery('body');
    app.go.nav = jQuery('nav#block-janitor-main-menu');

    // Dynamic values.
    app.go.winTop = app.go.win.scrollTop();
    app.go.winWidth = app.go.win.width();
    app.go.winHeight = app.go.win.height();

    if (app.go.winWidth < 960) {
      app.go.isMobile = true;
    }
    else {
      app.go.isMobile = false;
    }

  },

  // Sticky header.
  stickyHeader: function () {

    'use strict';

    var header = jQuery('header#page-header');

    if (header.hasClass('header-sticky')) {

      var elementB = jQuery('.header-sticky-before');
      var elementA = jQuery('.header-sticky-after');
      var heightB = elementB.outerHeight();

      if (app.go.winTop > heightB) {
        header.addClass('stick');
        elementA.addClass('header-stick');
      }
      else {
        header.removeClass('stick');
        elementA.removeClass('header-stick');
      }

    } return false;

  },

  // Navigation width.
  navWidth: function () {

    'use strict';

    var containerWidth = jQuery('.jcontainer').width();
    var marginValue = (app.go.winWidth - containerWidth) / 2;

    if (app.go.isMobile) {
      app.go.nav.css({
        width: app.go.winWidth,
        marginLeft: -marginValue,
        marginRight: -marginValue
      });
    }
    else {
      app.go.nav.css({
        width: '100%',
        marginLeft: 0,
        marginRight: 0
      });
    }

  },

  // Toggle navigation.
  toggleNav: function () {

    'use strict';

    var toggler = jQuery('.toggler');

    toggler.on('click', function () {

      if (app.go.isMobile) {
        if (app.go.isActive) {
          app.go.collapseNav();
        }
        else {
          app.go.expandNav();
        }
      } return false;

    });

  },

  // Expand navigation.
  expandNav: function () {

    'use strict';

    if (!app.go.isActive) {

      app.go.nav.show();
      jQuery('.toggler').addClass('open');
      if (jQuery('.header-fixed').length === 0 && jQuery('.header-sticky').length === 0) {
        app.go.body.css({
          overflowY: 'hidden',
          position: 'fixed'
        });
      }
      jQuery('.blackout').show();
    }
    app.go.isActive = true;

    app.go.navScroll();

  },

  // Collapse navigation.
  collapseNav: function () {

    'use strict';

    if (app.go.isActive) {
      app.go.nav.hide();
      jQuery('.toggler').removeClass('open');
      if (jQuery('.header-fixed').length === 0 && jQuery('.header-sticky').length === 0) {
        app.go.body.css({
          overflowY: 'visible',
          position: 'relative'
        });
      }
      jQuery('.blackout').hide();
    }
    app.go.isActive = false;

  },

  // Mobile toggle expandable items.
  mobileMenuItemsToggle: function () {

    'use strict';

    var menuItemSpan = app.go.nav.find('li > span');

    if (app.go.isMobile) {
      app.go.spanInit = true;
      menuItemSpan.on('click', function () {

        var self = jQuery(this);

        self.children('i').toggleClass('fa-chevron-up').toggleClass('fa-chevron-down').toggleClass('active');
        self.siblings('ul').toggleClass('active');

        self.closest('li').toggleClass('active-li');

      });
    }

  },

  // Collapse mobile expandable items.
  mobileMenuItemsCollapse: function () {

    'use strict';

    var menuItemSpan = app.go.nav.find('li > span');

    menuItemSpan.children('i').removeClass('fa-chevron-up').addClass('fa-chevron-down').removeClass('active');
    menuItemSpan.siblings('ul').removeClass('active');

    menuItemSpan.parent('li').removeClass('active-li');

  },

  // Add scroll to navigation.
  navScroll: function () {

    'use strict';

    if (app.go.isActive && app.go.isMobile) {

      var topHeight = 120;

      app.go.nav.css({
        height: app.go.winHeight - topHeight
      });

    }

  },

  // Accordion.
  initAccordion: function () {

    'use strict';

    // Variables.
    var indi = false;
    var accordion = jQuery('.jaccordion');
    var expand = jQuery('.is-expanded');

    // If items independent from siblings.
    if (accordion.hasClass('is-independent')) {
      indi = true;
    }

    // Fade/Hide items on initial load.
    jQuery('.itemContents')
      .css('opacity', 0)
      .each(function () {
        var getHeight = jQuery(this).find('.itemContents').height();
        jQuery(this).find('.itemContents').css('height', getHeight);
      });
    accordion.find('.itemContents').hide();

    // Show items with .is-expanded class.
    expand.find('.itemContents')
      .show()
      .css('opacity', 1);
    expand.find('.icon').html('<i class="fa fa-chevron-up"></i>');

    // On click.
    jQuery('.bar').on('click', function () {
      var self = jQuery(this);

      // Fade/Hide all items.
      if (indi === false) {
        self.parent().parent().children('.is-expanded').find('.itemContents').animate({opacity: 0}, function () {
          jQuery(this).slideUp(function () {
            jQuery(this).parent().removeClass('is-expanded');
          });
        });
      }

      // Expand/Show if not already showing.
      if (self.parent().hasClass('is-expanded')) {
        if (indi === true) {
          self.siblings('.itemContents').animate({opacity: 0}, function () {
            jQuery(this).slideUp();
            jQuery(this).closest('.jaccordion>li').removeClass('is-expanded');
          });
        }
      }
      else {
        self.siblings('.itemContents').slideDown(function () {
          jQuery(this).animate({opacity: 1});
          jQuery(this).closest('.jaccordion>li').addClass('is-expanded');
        });
      }
    });

  },

  // Tabber.
  initTabber: function () {

    'use strict';

    jQuery('ul.jtabber>li').on('click', function () {
      var self = jQuery(this);
      var dataContent = self.attr('data-contents');
      var tabberContent = self.parent('ul').siblings('.jtabberContent');

      if (!self.parent().hasClass('open')) {
        self.siblings().removeClass('open');
        self.addClass('open');

        tabberContent.children('li[data-tab!=' + dataContent + ']').hide();
        tabberContent.children('li[data-tab=' + dataContent + ']').show();
      }
    });

  },

  // Equal heights.
  equalHeights: function () {

    'use strict';

    var row = jQuery('.equalize');

    row.each(function () {

      var item = jQuery(this).find('.jcol').not('.no-equalize');

      if (app.go.winWidth > 767) {

        var tallest = 0;

        item.height('auto');

        item.each(function () {
          var iHeight = jQuery(this).height();

          tallest = tallest > iHeight ? tallest : iHeight;
        });

        item.height(tallest);
      }
      else {
        item.height('auto');
      }

    });

    jQuery('.pager').find('a').on('click', function () {
      setTimeout(function () {
        app.go.win.trigger('resize');
      }, 600);
    });

  },

  // Sidebar height.
  sidebarHeight: function () {

    'use strict';

    var container = jQuery('.jcontainer-has-sidebar, .jcontainer-has-sidebar-both');

    container.each(function () {

      var side = jQuery(this).find('.jsidebar').not('.no-calculate');
      var main = jQuery(this).find('.jcontent').not('.no-calculate');

      side.height('auto');
      main.height('auto');

      if (app.go.winWidth > 768) {

        var tallest = 0;
        var sHeight = side.height();
        var mHeight = main.height();

        if (sHeight > mHeight) {
          tallest = sHeight;
        }
        else {
          tallest = mHeight;
        }

        side.height(tallest);
        main.height(tallest);

      }
      else {
        side.height('auto');
        main.height('auto');
      }

    });

  },

  // Disable middle mouse click.
  disableMiddleMouse: function () {

    'use strict';

    app.go.body.on('mousedown', function (e) {

      if (e.which === 2) {
        e.preventDefault();
      }

    });

  }

};
